;; Generated package description from gnosis.el  -*- mode: lisp-data; no-byte-compile: t; lexical-binding:t -*-
(define-package "gnosis" "0.10.5.0.20260507.183225" "Knowledge System" '((emacs "29.1") (compat "29.1.4.2") (keymap-popup "0.2.0")) :commit "5d46bc6242c6eb8b710b6b31a60d699a7482ca2d" :authors '(("Thanos Apollo" . "public@thanosapollo.org")) :maintainer '("Thanos Apollo" . "public@thanosapollo.org") :keywords '("extensions") :url "https://codeberg.org/thanosapollo/emacs-gnosis")
